@@ -31,8 +31,11 @@ check_length_val <- function(length_x, n, header, reason = NULL, .abort = abort)
     return()
   }
 
-  if (is.null(reason)) reason <- ""
-  else reason <- glue(" ({reason})")
+  if (is.null(reason)) {
+    reason <- ""
+  } else {
+    reason <- glue(" ({reason})")
+  }
 
   if (n == 1) {
     glubort(header, "must be length 1{reason}, not {commas(length_x)}", .abort = .abort)
@@ -46,7 +49,7 @@ check_type <- function(x, template, header) {
     return()
   }
 
-  glubort(header, "must be type {type_of(template)}, not {typeof(x)}")
+  glubort(header, "must be {friendly_type_of(template)}, not {friendly_type_of(x)}")
 }
 
 check_class <- function(x, template, header) {
@@ -58,5 +61,7 @@ check_class <- function(x, template, header) {
     return()
   }
 
-  glubort(header, "must be {fmt_classes(template)}, not {fmt_classes(x)}")
+  exp_classes <- fmt_classes(template)
+  out_classes <- fmt_classes(x)
+  glubort(header, "must have class `{exp_classes}`, not class `{out_classes}`")
 }
