@@ -6,6 +6,8 @@
   toset <- !(names(op.dplyr) %in% names(op))
   if (any(toset)) options(op.dplyr[toset])
 
+  compat_lengths()
+
   invisible()
 }
 
@@ -24,13 +26,3 @@
 .onDetach <- function(libpath) {
   setHook(packageEvent("plyr", "attach"), NULL, "replace")
 }
-
-when_attached <- function(pkg, action) {
-  if (is_attached(pkg)) {
-    action
-  } else {
-    setHook(packageEvent(pkg, "attach"), function(...) action)
-  }
-}
-
-is_attached <- function(pkg) paste0("package:", pkg) %in% search()
